# Multivariable Newton-Raphson Example

import numpy as np

def multinewt(f,J,x0,Ea=1.e-7,maxiter=30,decel=1.0):
    xold = x0
    for iter in range(maxiter):
        Jinv = np.linalg.inv(J(xold))
        xnew = xold - decel*Jinv.dot(f(xold))
        xdev = xnew - xold
        xerr = xdev.dot(xdev)
        if xerr < Ea:
            break
        xold = xnew
    return xnew,iter+1

def f(x):
    fn = np.zeros(2)
    fn[0] = x[0]**2 + x[1]**2 - 4
    fn[1] = x[0]*x[1] -1
    return fn

def J(x):
    Jac = np.zeros((2,2))
    Jac[0,0] = 2*x[0]
    Jac[0,1] = 2*x[1]
    Jac[1,0] = x[1]
    Jac[1,1] = x[0]
    return Jac

x0 = np.array([0.5, 1.4])
xsoln,niter = multinewt(f,J,x0)
print(xsoln)
print(niter)

