import numpy as np
import matplotlib.pyplot as plt
import statsmodels.api as ssm

wtpct = np.array([1.,2.,4.,8.,12.,16.,20.,24.,26.])
T = np.array([0.,10.,25.,40.,60.,80.,100.])
Den = np.loadtxt('SaltDensity.csv',delimiter=',',unpack=True)

n1 = len(wtpct)
n2 = len(T)
n = n1*n2

wn = np.zeros(n)
Tn = np.zeros(n)
y = np.reshape(Den,(n,1),order='F')
y = y.flatten()

for i in range(n1):
    for j in range(n2):
        wn[i*n2+j] = wtpct[i]
        Tn[i*n2+j] = T[j]
    
X = np.column_stack((np.ones(n), wn, Tn, wn**2, Tn**2, wn*Tn))

mod = ssm.OLS(y,X)
result = mod.fit()

print(result.params)
print('\n',result.summary())


b = result.params
yp = X.dot(b)
resid = y - yp

plt.scatter(y,yp,marker='.',c='k')
plt.grid()
plt.xlabel('Measured Density')
plt.ylabel('Predicted Density')

plt.figure()
plt.plot(yp,resid,c='w',marker='s',mec='k',mfc='w')
plt.grid()
plt.xlabel('Predicted Density')
plt.ylabel('Residual')

