import numpy as np
import matplotlib.pyplot as plt
from scipy.optimize import minimize

def SSE(x,T,LVP):
    A = x[0]
    B = x[1]
    C = x[2]
    LVPM = A - B / (C + T)
    VPerr = LVP - LVPM
    return VPerr.dot(VPerr)

T,VP = np.loadtxt('H2SO4VaporPressure.txt',unpack=True)

LVP = np.log10(VP)

A = 10 ; B = 2000 ; C = 250
x0 = [ A, B, C ]

result = minimize(SSE,x0,args=(T,LVP))
print(result)

A = result.x[0]
B = result.x[1]
C = result.x[2]

Tplot = np.linspace(np.min(T),np.max(T),100)
LVplot = A - B / (C + Tplot)

print('A = {0:7.4f}, B = {1:7.1f}, C = {2:7.2f}'.format(A,B,C))

plt.plot(T,LVP,c='w',marker='s',mec='k',mfc='w',label='data')
plt.plot(Tplot,LVplot,c='k',label='Antoine Eqn')
plt.grid()
plt.xlabel('Temperature - degC')
plt.ylabel('log10(Vapor Pressure)')
plt.legend()

