import numpy as np
from scipy.optimize import root

R = 8314.  # Pa*m3/(kmol*K)
MW = 18.02  # kg/kmol
# Antoine coefficients
A = 11.21 ; B = 2354.7 ; C = 280.7

def SteamEq(x,m,V):
    P = x[0]
    T = x[1]
    ferr = np.zeros(2)
    ferr[0] = (P*V - m/MW*R*(T+273.15))/1e5
    ferr[1] = np.log10(P) - A + B/(T+C)
    return ferr

m = 3.755  # kg
V = 3.142  # m3

x0 = [ 2.e5, 110.]

result = root(SteamEq,x0,args=(m,V))
print('\nsolution is:')
print('P = {0:5.1f} kPa'.format(result.x[0]/1000))
print('T = {0:6.1f} degC'.format(result.x[1]))

