def bisect(func,x1,x2,maxit=20):
    """
    Uses the bisection method to estimate a root of func(x).
    The method is iterated maxit (default = 20) times.
    Input:
        func = name of the function
        x1 = lower guess
        x2 = upper guess
    Output:
        xmid = root estimate
        or
        error message if initial guesses do not bracket solution
    """
    if func(x1)*func(x2)>0:
        return 'initial estimates do not bracket solution'
    for i in range(maxit): # carry out maxit iterations
        xmid = (x1+x2)/2  # calculate midpoint
        if func(xmid)*func(x1)>0:  # check if f(xmid) same sign as f(x1)
            x1 = xmid   # if so, replace x1 with xmid
        else:
            x2 = xmid  # if not, replace x2 with xmid
    return xmid  # return the latest value of xmid as the solution

import numpy as np

def f(x):
    return np.sin(x+2)*np.cosh(x)+2.

x1 = 0. ; x2 = 3.
xsoln = bisect(f,x1,x2)
print('solution is {0:6.4f}'.format(xsoln))

