import numpy as np
import matplotlib.pyplot as plt
from scipy.integrate import solve_ivp

def htxr(z,T,hi,ho,Ai,Ao,wc,wh,cP):
    Tc = T[0]
    Th = T[1]
    dTc = hi*Ai/wc/cP*(Th-Tc)
    dTh = ho*Ao/wh/cP*(Th-Tc)
    return [dTc, dTh]

doin = 1.  # in
do = doin * 0.0254  # m
Ao = np.pi*do  # m2/m
diin = 0.76  # in
di = diin * 0.0254  # m
Ai = np.pi*di  # m2/m
L = 5.  # m

den = 998.  # kg/m3
cP = 4187.  # J/(kg*degC)

hi = 14000.  # W/(m2*degC)
ho = hi*di/do

qcL = 0.3  # L/s
qc = qcL/1000.  # m3/s
wc = qc * den  # kg/s
qhL = 1.  # L/s
qh = qhL/1000.  # m3/s
wh = qh * den  # kg/s

Tci = 10  # degC
Thi = 50  # degC

zspan = [0., L]
zeval = np.linspace(0.,L,100)

Tho = 40  #  degC

T0 = [ Tci, Tho]

result = solve_ivp(htxr,zspan,T0,t_eval=zeval \
                   ,args=(hi,ho,Ai,Ao,wc,wh,cP))

zs = result.t
Tc = result.y[0,:]
Th = result.y[1,:]

plt.plot(zs,Tc,c='b',label='Cold Stream')
plt.plot(zs,Th,c='r',label='Hot Stream')
plt.grid()
plt.xlabel('Distance - m')
plt.ylabel('Temperature - degC')
plt.legend()




