import numpy as np
from scipy.optimize import minimize

def S(x):  # bin surface area
    r = x[0]
    hcyl = x[1]
    hcon = x[2]
    Scyl = 2*np.pi*r*hcyl
    Scon = np.pi*r*np.sqrt(r**2+hcon**2)
    return Scyl+Scon

def V(x):  # bin volume
    r = x[0]
    hcyl = x[1]
    hcon = x[2]
    Vcyl = np.pi*r**2*hcyl
    Vcon = np.pi*r**2*hcon/3
    return Vcyl+Vcon

def VolCon(x):  # volume equality constraint
    return V(x)-Volspec

def AngCon(x):  # cone angle inequality constraint
    r = x[0]
    hcon = x[2]
    Angrad = np.arctan(r/hcon)
    Angdeg = np.rad2deg(Angrad)
    return Angspec - Angdeg  # must be >= 0
    
Volspec = 10  # m**3
Angspec = 20.4  # deg
x0 = [1., 1., 1.]  # m
con = ({'type':'eq','fun':VolCon},  
       {'type':'ineq','fun':AngCon})

result = minimize(S,x0,constraints=con)

r = result.x[0]
hcyl = result.x[1]
hcon = result.x[2]
print('radius = {0:5.2f} m'.format(r))
print('cylinder height = {0:5.2f} m'.format(hcyl))
print('cone height = {0:5.2f} m'.format(hcon))
phi = np.arctan(r/hcon)
phid = np.rad2deg(phi)
print('cone angle = {0:5.1f} deg'.format(phid))
print('total surface area = {0:6.1f} m2'.format(S(result.x)))
print('bin volume = {0:5.1f} m3'.format(V(result.x)))

