import numpy as np
import matplotlib.pyplot as plt
from scipy.integrate import solve_ivp

def multibatch(t,y,k1,k2,k3):
    A = y[0] ; B = y[1] ; C = y[2] ; D = y[3]
    dA = -k1*A*B - k2*A*C - k3*A*D
    dB = -k1*A*B
    dC = k1*A*B - k2*A*C
    dD = k2*A*C - k3*A*D
    return [dA, dB, dC, dD]

k1 = 14.7
k2 = 1.53
k3 = 0.294
A0 = 0.0209
B0 = A0/3

tspan = [ 0., 500.]
teval = np.linspace(0.,500.,100)
y0 = [A0, B0, 0, 0]

result = solve_ivp(multibatch,tspan,y0,t_eval=teval,args=(k1,k2,k3))

tm = result.t
A = result.y[0,:]
B = result.y[1,:]
C = result.y[2,:]
D = result.y[3,:]

E = (A0 - A - C - 2*D)/3
F = A0 - A

plt.plot(tm,A,c='b',label='A')
plt.plot(tm,B,c='r',label='B')
plt.plot(tm,C,c='m',label='C')
plt.plot(tm,D,c='k',label='D')
plt.plot(tm,E,c='c',label='E')
plt.plot(tm,F,c='g',label='F')
plt.grid()
plt.xlabel('Time - min')
plt.ylabel('Concentration - mol/L')
plt.legend()


